@@ -125,7 +125,7 @@ def mpc(channel):
     return channel.get('mpc')
 
 
-xp_pullchannel = 'child::cppa:PullChannelId'
+xp_pullchannel = 'child::cppa:PullHandling/cppa:PullChannelId'
 def references_pull_channel(ebms3binding):
     pullchannels = ebms3binding.xpath(xp_pullchannel, namespaces=NSMAP)
     if len(pullchannels) == 0:
@@ -133,7 +133,7 @@ def references_pull_channel(ebms3binding):
     else:
         return True
 
-xp_pullchannel_id = 'child::cppa:PullChannelId/text()'
+xp_pullchannel_id = 'child::cppa:PullHandling/cppa:PullChannelId/text()'
 
 xp_soapversion = 'child::cppa:SOAPVersion/text()'
 def soapversion(binding):
@@ -476,6 +476,15 @@ pmode_json_schema = {
                               "required" : [# "WSSVersion",
                                             "PModeAuthorize"],
                               "additionalProperties" : False
+                },
+                "PayloadService" : {
+                    "type" : "object",
+                    "properties" : {
+                        "CompressionType" : {
+                            "type" : "string"
+                        }
+                    },
+                    "additionalProperties" : False
                 }
             },
             "required" : ["Protocol",
