@@ -170,6 +170,30 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_0024(self):
         self.do_unification('0024')
 
+    # to do Wildcard service
+
+    # MaxSize
+    # Specified on both sides, first higher
+    def test_0026(self):
+        self.do_unification('0026')
+
+    # Specified on first side only
+    def test_0027(self):
+        self.do_unification('0027')
+
+    # Specified on second side only
+    def test_0028(self):
+        self.do_unification('0028')
+
+
+    # Tests to show that unification is not commutative, illustrating depth-first
+    # backtracking search
+    def test_0030(self):
+        self.do_unification('0030')
+
+    def test_0031(self):
+        self.do_unification('0031')
+
     # Extra test, failing ActivationDate
     def test_0050(self):
         self.assertRaises( cppa3.unify.UnificationException, self.do_unification, '0210' )
@@ -182,6 +206,10 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_0060(self):
         self.do_unification('0060')
 
+    # Variant of 1020 using NamedChannel
+    def test_0061(self):
+        self.do_unification('0061')
+
     """
     Payload Profile
     """
@@ -347,7 +375,6 @@ class CPPA3TestCase( unittest.TestCase ):
         self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '0503')
 
 
-
     """
     ebBP attributes test
 
@@ -393,6 +420,10 @@ class CPPA3TestCase( unittest.TestCase ):
         self.do_unification('1012')
 
 
+    def test_1020(self):
+        # Variant of 1011 that uses channel features
+        self.do_unification('1020')
+
     # ENTSOG AS4 tests
     # To do
 
@@ -650,6 +681,11 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_2120(self):
         self.do_unification('2120')
 
+    # Multiple Matching SignatureAlgorithms,  only first one selected
+    def test_2121(self):
+        self.do_unification('2121')
+
+
     # @@@ add some variations
 
     # SignAttachments
@@ -1004,6 +1040,65 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_9006(self):
         self.assertRaises(cppa3.unify.UnificationException, self._test_9006)
 
+    def test_9007(self):
+        logging.info('Running test 9007')
+        unifier = cppa3.unify.CPABuilder(nsmap={'ns':'urn:namespace',
+                                                'ns2':'urn:namespace2'})
+
+        a_element = lxml.etree.fromstring("""<ns:a xmlns:ns="urn:namespace" xmlns:ns2="urn:namespace2">
+        <ns2:b>value1</ns2:b>
+        <ns2:b>value2</ns2:b>
+        </ns:a>
+        """)
+        b_element = lxml.etree.fromstring("""<ns:a xmlns:ns="urn:namespace" xmlns:ns2="urn:namespace2">
+        <ns2:b>value1</ns2:b>
+        <ns2:b>value2</ns2:b>
+        </ns:a>
+        """)
+        ab_element = lxml.etree.fromstring("""
+        <ns:a xmlns:ns="urn:namespace" xmlns:ns2="urn:namespace2"/>
+        """)
+        unifier.unify_simple_subelement(a_element,
+                                        b_element,
+                                        ab_element,
+                                        'ns2',
+                                        'b',
+                                        intersectifmultiple=True,
+                                        strictelements=True,
+                                        required=False)
+
+        logging.debug(lxml.etree.tostring(ab_element, pretty_print=True))
+
+    def test_9008(self):
+        logging.info('Running test 9008')
+        unifier = cppa3.unify.CPABuilder(nsmap={'ns':'urn:namespace',
+                                                'ns2':'urn:namespace2'})
+
+        a_element = lxml.etree.fromstring("""<ns:a xmlns:ns="urn:namespace" xmlns:ns2="urn:namespace2">
+        <ns2:b>value1</ns2:b>
+        <ns2:b>value2</ns2:b>
+        </ns:a>
+        """)
+        b_element = lxml.etree.fromstring("""<ns:a xmlns:ns="urn:namespace" xmlns:ns2="urn:namespace2">
+        <ns2:b>value2</ns2:b>
+        <ns2:b>value1</ns2:b>
+        </ns:a>
+        """)
+        ab_element = lxml.etree.fromstring("""
+        <ns:a xmlns:ns="urn:namespace" xmlns:ns2="urn:namespace2"/>
+        """)
+        unifier.unify_simple_subelement(a_element,
+                                        b_element,
+                                        ab_element,
+                                        'ns2',
+                                        'b',
+                                        intersectifmultiple=True,
+                                        strictelements=True,
+                                        required=False)
+
+        logging.debug(lxml.etree.tostring(ab_element, pretty_print=True))
+
+
 def reset_timestamped_values_for_compare(cpa):
     cpa_to_edit = deepcopy(cpa)
     for path in [
